@@ -13,6 +13,7 @@ The method can be:
     or any other function that outputs an integer with an input of two ndarrays.        
 """
 
-from boolfuncs_py import *
+from boolfuncs import *
+
 
 
